import json
import ast

def de_anonymize(anonymized_object, map_object=None, map_file_path=None, output_file_path=None):
    if map_file_path:
        with open(map_file_path, 'r') as f:
            map_object = json.load(f)
    
    if not map_object:
        raise ValueError("A map_object or map_file_path must be provided.")
        
    if isinstance(anonymized_object, str):
        with open(anonymized_object, 'r') as f:
            anonymized_object = json.load(f)

    keys_map = map_object["keys"]
    values_map = map_object["values"]

    def de_anonymize_recursive(obj):
        if isinstance(obj, dict):
            de_anonymized_dict = {}
            for key, value in obj.items():
                orig_key = None
                
                if keys_map:  # Check if keys_map is populated
                    orig_key = [k for k, v in keys_map.items() if v == key][0]
                else:
                    orig_key = key

                orig_value = de_anonymize_recursive(value)

                de_anonymized_dict[orig_key] = orig_value

            return de_anonymized_dict

        elif isinstance(obj, list):
            return [de_anonymize_recursive(item) for item in obj]

        else:
            value = [k for k, v in values_map.items() if v == obj][0]
            try:
                return ast.literal_eval(value)
            except (ValueError, SyntaxError):
                return value

    de_anonymized_object = de_anonymize_recursive(anonymized_object)

    if output_file_path:
        with open(output_file_path, 'w') as f:
            json.dump(de_anonymized_object, f, indent=2)
    else:
        return de_anonymized_object


import json
from collections.abc import MutableMapping

def anonymize(json_input, map_file_path=None, anonymized_file_path=None, anonymize_keys=True):
    key_counter = 1
    value_counter = 1
    keys_map = {}
    values_map = {}

    if isinstance(json_input, str):
        with open(json_input, 'r') as f:
            json_object = json.load(f)
    else:
        json_object = json_input

    def anonymize_recursive(obj):
        nonlocal key_counter, value_counter

        if isinstance(obj, dict):
            anonymized_dict = {}
            for key, value in obj.items():
                if anonymize_keys and key not in keys_map:
                    keys_map[key] = f"k{key_counter}"
                    key_counter += 1

                anon_key = keys_map.get(key, key) if anonymize_keys else key
                anon_value = anonymize_recursive(value)

                anonymized_dict[anon_key] = anon_value

            return anonymized_dict

        elif isinstance(obj, list):
            return [anonymize_recursive(item) for item in obj]

        else:
            str_obj = str(obj)
            if str_obj not in values_map:
                values_map[str_obj] = f"v{value_counter}"
                value_counter += 1

            return values_map[str_obj]

    anonymized_object = anonymize_recursive(json_object)
    map_object = {"keys": keys_map, "values": values_map}

    # Save the map file if a path is provided
    if map_file_path:
        save_map(map_object, map_file_path)

    # Save the anonymized JSON object if a path is provided
    if anonymized_file_path:
        with open(anonymized_file_path, 'w') as f:
            json.dump(anonymized_object, f, indent=2)

    return anonymized_object, map_object

def save_map(map_object, filename):
    with open(filename, 'w') as f:
        json.dump(map_object, f, indent=2)


import os
import json
import unittest
import tempfile
from prompt_horizon.de_anonymizer import de_anonymize
from prompt_horizon.anonymizer import anonymize, save_map

class TestDeAnonymizer(unittest.TestCase):
    def test_de_anonymize(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_deanonymized_json = {"name": "John", "age": 30, "city": "New York"}

        anonymized_json, map_object = anonymize(input_json)
        deanonymized_json = de_anonymize(anonymized_json, map_object=map_object)

        self.assertEqual(deanonymized_json, expected_deanonymized_json)

    def test_de_anonymize_with_map_file_path(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_deanonymized_json = {"name": "John", "age": 30, "city": "New York"}

        anonymized_json, map_object = anonymize(input_json)

        # Create a temporary map file
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix=".json") as temp_file:
            save_map(map_object, temp_file.name)
            temp_map_file_path = temp_file.name

        deanonymized_json = de_anonymize(anonymized_json, map_file_path=temp_map_file_path)

        self.assertEqual(deanonymized_json, expected_deanonymized_json)

        # Clean up the temporary file
        os.remove(temp_map_file_path)

    def test_de_anonymize_with_output_file_path(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_deanonymized_json = {"name": "John", "age": 30, "city": "New York"}

        anonymized_json, map_object = anonymize(input_json)

        # Create a temporary output file path
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix=".json") as temp_file:
            temp_output_file_path = temp_file.name

        de_anonymize(anonymized_json, map_object=map_object, output_file_path=temp_output_file_path)

        # Check if the de-anonymized JSON is saved to the specified file location
        with open(temp_output_file_path, 'r') as f:
            saved_deanonymized_json = json.load(f)

        self.assertEqual(saved_deanonymized_json, expected_deanonymized_json)

        # Clean up the temporary file
        os.remove(temp_output_file_path)

    def test_de_anonymize_with_anonymized_file_input(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_deanonymized_json = {"name": "John", "age": 30, "city": "New York"}

        anonymized_json, map_object = anonymize(input_json)

        # Create a temporary anonymized file
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix=".json") as temp_file:
            json.dump(anonymized_json, temp_file)
            temp_anonymized_file_path = temp_file.name

        deanonymized_json = de_anonymize(temp_anonymized_file_path, map_object=map_object)

        self.assertEqual(deanonymized_json, expected_deanonymized_json)

        # Clean up the temporary file
        os.remove(temp_anonymized_file_path)

    def test_de_anonymize_values_only(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_deanonymized_json = {"name": "John", "age": 30, "city": "New York"}

        # Anonymize the input JSON with only values
        anonymized_json, map_object = anonymize(input_json, anonymize_keys=False)

        deanonymized_json = de_anonymize(anonymized_json, map_object=map_object)

        self.assertEqual(deanonymized_json, expected_deanonymized_json)


if __name__ == '__main__':
    unittest.main()



import unittest
from prompt_horizon.anonymizer import anonymize, save_map
from prompt_horizon.de_anonymizer import de_anonymize

class TestAnonymizerComplex(unittest.TestCase):
    def test_anonymize_complex(self):
        json_object = {
            "person": {
                "name": "John",
                "age": 30,
                "city": "New York",
                "contact": {
                    "email": "john@example.com",
                    "phone": "555-555-5555",
                    "address": {
                        "street": "123 Main St",
                        "city": "New York",
                        "zipcode": 10001,
                        "country": "USA",
                    },
                },
                "siblings": [
                    {"name": "Jane", "age": 28, "city": "New York"},
                    {"name": "Jim", "age": 32, "city": "Los Angeles"},
                ],
            }
        }

        anonymized_object, map_object = anonymize(json_object)
        de_anonymized_object = de_anonymize(anonymized_object, map_object)

        self.assertEqual(json_object, de_anonymized_object)

        # Save the map_object to a file for manual inspection
        save_map(map_object, 'test_complex_map.json')

if __name__ == "__main__":
    unittest.main()



import tempfile
import os
import json
import unittest
from prompt_horizon.anonymizer import anonymize


class TestAnonymizer(unittest.TestCase):
    def test_anonymize(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_anonymized_json = {"k1": "v1", "k2": "v2", "k3": "v3"}
        expected_map_object = {
            "keys": {"name": "k1", "age": "k2", "city": "k3"},
            "values": {"John": "v1", "30": "v2", "New York": "v3"}
        }

        anonymized_json, map_object = anonymize(input_json)

        self.assertEqual(anonymized_json, expected_anonymized_json)
        self.assertEqual(map_object, expected_map_object)

    def test_anonymize_with_file(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_anonymized_json = {"k1": "v1", "k2": "v2", "k3": "v3"}
        expected_map_object = {
            "keys": {"name": "k1", "age": "k2", "city": "k3"},
            "values": {"John": "v1", "30": "v2", "New York": "v3"}
        }

        # Create a temporary JSON file
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix=".json") as temp_file:
            json.dump(input_json, temp_file)
            temp_file_path = temp_file.name

        # Call the anonymize function with the file path
        anonymized_json, map_object = anonymize(temp_file_path)

        self.assertEqual(anonymized_json, expected_anonymized_json)
        self.assertEqual(map_object, expected_map_object)

        # Clean up the temporary file
        os.remove(temp_file_path)

    def test_anonymize_with_map_file_path(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}

        # Create a temporary directory to save the map file
        with tempfile.TemporaryDirectory() as temp_dir:
            map_file_path = os.path.join(temp_dir, "map.json")

            anonymized_json, map_object = anonymize(input_json, map_file_path)

            # Check if the map file exists at the specified location
            self.assertTrue(os.path.exists(map_file_path))

            # Load the map file and compare it with the map_object
            with open(map_file_path, 'r') as f:
                loaded_map_object = json.load(f)

            self.assertEqual(map_object, loaded_map_object)

    def test_anonymize_with_anonymized_file_path(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_anonymized_json = {"k1": "v1", "k2": "v2", "k3": "v3"}

        # Create a temporary directory to save the anonymized JSON file
        with tempfile.TemporaryDirectory() as temp_dir:
            anonymized_file_path = os.path.join(temp_dir, "anonymized.json")

            anonymized_json, map_object = anonymize(input_json, anonymized_file_path=anonymized_file_path)

            # Check if the anonymized JSON file exists at the specified location
            self.assertTrue(os.path.exists(anonymized_file_path))

            # Load the anonymized JSON file and compare it with the anonymized_json
            with open(anonymized_file_path, 'r') as f:
                loaded_anonymized_json = json.load(f)

            self.assertEqual(anonymized_json, loaded_anonymized_json)

    def test_anonymize_no_key_anonymization(self):
        input_json = {"name": "John", "age": 30, "city": "New York"}
        expected_anonymized_json = {"name": "v1", "age": "v2", "city": "v3"}
        expected_map_object = {
            "keys": {},
            "values": {"John": "v1", "30": "v2", "New York": "v3"}
        }

        anonymized_json, map_object = anonymize(input_json, anonymize_keys=False)

        self.assertEqual(anonymized_json, expected_anonymized_json)
        self.assertEqual(map_object, expected_map_object)


if __name__ == '__main__':
    unittest.main()




import os
from setuptools import setup, find_packages

def read_file(filename):
    with open(os.path.join(os.path.dirname(__file__), filename), encoding='utf-8') as f:
        return f.read()


setup(
    name='prompt-horizon',
    version='0.1.4',
    description='Library to anonymize JSON objects by creating placeholders for keys and values, while generating a reversible mapping to restore afterwards',
    long_description=read_file('README.md'),
    long_description_content_type='text/markdown',
    author='George Kanellopoulos',
    author_email='george@gkanellopoulos.com',
    url='https://github.com/gkanellopoulos/prompthorizon.git',
    packages=find_packages(),
    install_requires=[
        # List your library's dependencies here, e.g.:
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)